.. CGATReport documentation master file, created by
   sphinx-quickstart on Mon Mar 23 15:27:57 2009.

CGATReport documentation
============================

The cgatreport module is an extension for sphinx
that provides facilities for data retrieval and data rendering
within reStructured text. 

See :ref:`Installation` on how to build and test cgatreport. The
section :ref:`Overview` introduces the features of cgatreport. The
section :ref:`Background` contains required reading for anyone using
cgatreport.

If you are new to cgatreport, the :ref:`Tutorials` give you
step-by-step explanations. After completing the tutorial, the
:ref:`Reference` section lists all that comes with cgatreport.

The cgatreport module comes with additional utilities for to aid debugging
and the building of large documents. See :ref:`Utilities` for a full
list.

The :ref:`Running` section explains ways to build large document
effectively. See also the :ref:`Advanced topics` section.

Contents:

.. toctree::
   :maxdepth: 1

   Introduction.rst   
   Overview.rst
   Background.rst
   Tutorials.rst
   UseCase.rst
   ComplexDocuments.rst
   DataMapping.rst
   TipsTricks.rst
   Reference.rst
   Running.rst
   Advanced.rst
   Glossary.rst
   Developing.rst
   Roadmap.rst
   Examples.rst
   Test.rst
   FAQ.rst
   Errors.rst


